@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Updater
 #  read the maintenance settings
@@ -36,7 +35,6 @@
 import os
 from shlex import quote
 from sys import exit
-from typing import Dict, List
 
 from univention.config_registry import ConfigRegistry
 from univention.lib.policy_result import PolicyResultFailed, policy_result
@@ -70,7 +68,7 @@ def write_cron_job(configRegistry: ConfigRegistry, cron: str, updateto: str, reb
         print('%s\troot\t%s' % (cron, ';'.join(cmd)), file=file)
 
 
-def one(results: Dict[str, List[str]], key: str) -> str:
+def one(results: dict[str, list[str]], key: str) -> str:
     try:
         return results[key][0]
     except LookupError:
