@@ -39,7 +39,7 @@ def log(mockopen):
     mockopen.write("/var/log/univention/updater.log", b"")
 
 
-class TestUniventionUpdater(object):
+class TestUniventionUpdater:
     """Unit test for univention.updater.tools"""
 
     def test_config_repository(self, ucr, u):
@@ -205,7 +205,7 @@ class TestUniventionUpdater(object):
         u.run_dist_upgrade()
         cmds = mockpopen.mock_get()
         cmd = cmds[0]
-        if isinstance(cmd, (list, tuple)):
+        if isinstance(cmd, list | tuple):
             cmd = ' '.join(cmd)
         assert ' dist-upgrade' in cmd
 
@@ -308,7 +308,7 @@ class TestUniventionUpdater(object):
             next(gen)
 
 
-class TestComponents(object):
+class TestComponents:
 
     def test_get_components(self, ucr, u):
         """Test enabled components."""
